@@ -1,7 +1,10 @@
 from typing import Dict, List
 
-from ._version import __version__
-from .unfolded_jupyter import UnfoldedMap
+from unfolded.map_sdk._version import __version__
+from unfolded.map_sdk.api.create_map import create_map
+from unfolded.map_sdk.colab import enable_colab_custom_widgets
+
+enable_colab_custom_widgets()
 
 
 def _jupyter_labextension_paths() -> List[Dict[str, str]]:
@@ -16,7 +19,7 @@ def _jupyter_labextension_paths() -> List[Dict[str, str]]:
         from `src` directory into <jupyter path>/labextensions/<dest> directory
         during widget installation
     """
-    return [{'src': 'labextension', 'dest': '@unfolded/jupyter-map-sdk'}]
+    return [{"src": "labextension", "dest": "@unfolded/jupyter-map-sdk"}]
 
 
 def _jupyter_nbextension_paths() -> List[Dict[str, str]]:
@@ -35,8 +38,11 @@ def _jupyter_nbextension_paths() -> List[Dict[str, str]]:
     require: Path to importable AMD Javascript module inside the
         <jupyter path>/nbextensions/<dest> directory
     """
-    return [{
-        'section': 'notebook',
-        'src': 'nbextension',
-        'dest': 'unfolded/map_sdk',
-        'require': 'unfolded/map_sdk/extension'}]
+    return [
+        {
+            "section": "notebook",
+            "src": "nbextension",
+            "dest": "unfolded/map_sdk",
+            "require": "unfolded/map_sdk/extension",
+        }
+    ]
